<!DOCTYPE TS><TS>
<context>
    <name>AddRecording</name>
    <message>
        <source>Schedule a:</source>
        <translation>Køyreplan a:</translation>
    </message>
    <message>
        <source>&amp;Recording</source>
        <translation>&amp;Opptak</translation>
    </message>
    <message>
        <source>&amp;Playout</source>
        <translation>&amp;Utspeling</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Nedlasting</translation>
    </message>
    <message>
        <source>&amp;Upload</source>
        <translation>&amp;Opplasting</translation>
    </message>
    <message>
        <source>&amp;Macro Cart</source>
        <translation>&amp;Makrovogn</translation>
    </message>
    <message>
        <source>&amp;Switch Event</source>
        <translation>&amp;Byt hending</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>CatchListView</name>
    <message>
        <source>Edit Cue Markers</source>
        <translation>Rediger cue-markørar</translation>
    </message>
</context>
<context>
    <name>DeckMon</name>
    <message>
        <source>MON</source>
        <translation>MON</translation>
    </message>
    <message>
        <source>ABORT</source>
        <translation>AVBRYT</translation>
    </message>
    <message>
        <source>OFFLINE</source>
        <translation>AVLINJE</translation>
    </message>
    <message>
        <source>L</source>
        <translation>V</translation>
    </message>
    <message>
        <source>R</source>
        <translation>H</translation>
    </message>
    <message>
        <source>IDLE</source>
        <translation>LEDIG</translation>
    </message>
    <message>
        <source>READY</source>
        <translation>KLAR</translation>
    </message>
    <message>
        <source>WAITING</source>
        <translation>VENTAR</translation>
    </message>
    <message>
        <source>RECORDING</source>
        <translation>TEK OPP</translation>
    </message>
    <message>
        <source>PLAYING</source>
        <translation>SPELAR</translation>
    </message>
    <message>
        <source>[multiple events]</source>
        <translation>[fleire hendingar</translation>
    </message>
    <message>
        <source>[unknown cut]</source>
        <translation>[ukjent klipp]</translation>
    </message>
    <message>
        <source>[no description]</source>
        <translation>[inga skildring]</translation>
    </message>
</context>
<context>
    <name>EditCartEvent</name>
    <message>
        <source>Edit Cart Event</source>
        <translation>Rediger korghending</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Hendinga aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Plass:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Starttid:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Cart Number:</source>
        <translation>Korgnummer:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktiv dagar</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tysdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laurdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sundag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Lag enkeltskot</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Lagra som ny</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Kopier hending</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Det finst alt ei hending med dette oppsettet!</translation>
    </message>
    <message>
        <source>Invalid Cart</source>
        <translation>Ugyldig korg</translation>
    </message>
    <message>
        <source>That cart doesn&apos;t exist!</source>
        <translation>Den korga finst ikkje!</translation>
    </message>
</context>
<context>
    <name>EditDownload</name>
    <message>
        <source>Edit Download</source>
        <translation>Rediger nedlasting</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Hendinga aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Plass:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Starttid:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukarnamn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Mål:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanalar:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivå:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normaliser</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktiv dagar</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tysdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laurdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sundag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Lag enkeltskot</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Lagra som ny</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Kopier hending</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Det finst alt ei hending med dette oppsettet!</translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>Ugyldig adresse</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>Adressa er ugyldig!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>Ikkje støtta adresseprotokoll!</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Library Metadata</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditPlayout</name>
    <message>
        <source>Edit Playout</source>
        <translation>Rediger utspeling</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Hendinga aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Plass:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Starttid:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Mål:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktiv dagar</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tysdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laurdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sundag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Lag enkeltskot</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Lagra som ny</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation type="obsolete">Kopier hending</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation type="obsolete">Det finst alt ei hending med dette oppsettet!</translation>
    </message>
</context>
<context>
    <name>EditRecording</name>
    <message>
        <source>Edit Recording</source>
        <translation>Rediger opptak</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Hendinga aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Plass:</translation>
    </message>
    <message>
        <source>Start Parameters</source>
        <translation>Startoppsett</translation>
    </message>
    <message>
        <source>Use Hard Time</source>
        <translation>Bruk hardtid</translation>
    </message>
    <message>
        <source>Record Start Time:</source>
        <translation>Starttid for opptak:</translation>
    </message>
    <message>
        <source>Use GPI</source>
        <translation>Bruk GPI</translation>
    </message>
    <message>
        <source>Window Start Time:</source>
        <translation>Vindauge-starttid:</translation>
    </message>
    <message>
        <source>GPI Matrix:</source>
        <translation>GPI-matrise:</translation>
    </message>
    <message>
        <source>GPI Line:</source>
        <translation>GPI-linje:</translation>
    </message>
    <message>
        <source>Start Delay:</source>
        <translation>Startforseinking:</translation>
    </message>
    <message>
        <source>Allow Multiple Recordings within this Window</source>
        <translation>Gje løyve til fleire opptak i dette vindauget</translation>
    </message>
    <message>
        <source>End Parameters</source>
        <translation>Sluttoppsett</translation>
    </message>
    <message>
        <source>Use Length</source>
        <translation>Bruk lengd</translation>
    </message>
    <message>
        <source>Record Length:</source>
        <translation>Opptakslengd:</translation>
    </message>
    <message>
        <source>Record End Time:</source>
        <translation>Opptakssluttid:</translation>
    </message>
    <message>
        <source>Window End Time:</source>
        <translation>Vindaugssluttid:</translation>
    </message>
    <message>
        <source>Max Record Length:</source>
        <translation>Største opptakslengd:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Kjelde:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Mål:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanalar:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivå:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normaliser</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktiv dagar</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tysdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laurdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sundag</translation>
    </message>
    <message>
        <source>Start Date Offset:</source>
        <translation>Avvik for startdato:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ikkje noko</translation>
    </message>
    <message>
        <source>End Date Offset:</source>
        <translation>Avvik for sluttdato:</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Lag enkeltskot</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Lagra som
ny</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp</translation>
    </message>
    <message>
        <source>Missing Cut</source>
        <translation>Manglar klipp</translation>
    </message>
    <message>
        <source>You must assign a record cut!</source>
        <translation>Du må tildela eit opptaksklipp!</translation>
    </message>
    <message>
        <source>Record Parameter Error</source>
        <translation>Feil i opptaksoppsettet</translation>
    </message>
    <message>
        <source>The start GPI window cannot end before it begins!</source>
        <translation>Startvindauget for GPI kan ikkje byrja før det sluttar!</translation>
    </message>
    <message>
        <source>The recording cannot end before it begins!</source>
        <translation>Opptaket kan ikkje slutta før det byrjar!</translation>
    </message>
    <message>
        <source>The end GPI window cannot end before it begins!</source>
        <translation>Sluttvindauget for GPI kan ikkje slutta før det byrjar!</translation>
    </message>
    <message>
        <source>The start GPI matrix doesn&apos;t exist!</source>
        <translation>Startmatrisen for GPI finst ikkje!</translation>
    </message>
    <message>
        <source>The start GPI line doesn&apos;t exist!</source>
        <translation>Startlinja for GPI finst ikkje!</translation>
    </message>
    <message>
        <source>The end GPI matrix doesn&apos;t exist!</source>
        <translation>Sluttmatrisen for GPI finst ikkje!</translation>
    </message>
    <message>
        <source>The end GPI line doesn&apos;t exist!</source>
        <translation>Sluttlinja for GPI finst ikkje!</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Kopier hending</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Det finst alt ei hending med dette oppsettet!</translation>
    </message>
</context>
<context>
    <name>EditSwitchEvent</name>
    <message>
        <source>Edit Switcher Event</source>
        <translation>Rediger svitsjarhending</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Hendinga aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Plass:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Starttid:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Switch Matrix:</source>
        <translation>Byt matrise:</translation>
    </message>
    <message>
        <source>Switch Input:</source>
        <translation>Byt inngang:</translation>
    </message>
    <message>
        <source>Switch Output:</source>
        <translation>Byt utgang:</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktiv dagar</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laurdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sundag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Lag enkeltskot</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Lagra som
ny</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>--OFF--</source>
        <translation>--AV--</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Kopier hending</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Det finst alt ei hending med dette oppsettet!</translation>
    </message>
</context>
<context>
    <name>EditUpload</name>
    <message>
        <source>Edit Upload</source>
        <translation>Rediger opplasting</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Hendinga aktiv</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Plass:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Starttid:</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ingen]</translation>
    </message>
    <message>
        <source>RSS Feed:</source>
        <translation>RSS-straum:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Kjelde:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukarnamn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Export Format:</source>
        <translation>Eksportformat:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>S&amp;et</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normaliser</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivå:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Aktiv dagar</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tysdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laurdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sundag</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Lag enkeltskot</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Lagra som
ny</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Unsupported Format</source>
        <translation>Formatet er ikkje støtta</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on this host!</source>
        <translation>Dette eksportformatet er ikkje støtta på denne verten!</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Kopier hending</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Det finst alt ei hending med dette oppsettet!</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on host </source>
        <translation>Dette eksportformatet er ikkje støtta på denne verten </translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>Ugyldig adresse</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>Adressa er ugyldig!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>Ikkje støtta adresseprotokoll!</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Library Metadata</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation>RDLibrary-rapportar</translation>
    </message>
    <message>
        <source>Event Report</source>
        <translation>Hendingsrapport</translation>
    </message>
    <message>
        <source>Upload/Download Report</source>
        <translation>Opp- og nedlastingsrapport</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>La&amp;g</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCatch - Host:</source>
        <translation type="obsolete">RDCatch - vert:</translation>
    </message>
    <message>
        <source>rdcatch : </source>
        <translation>rdcatch:</translation>
    </message>
    <message>
        <source>Show Only Active Events</source>
        <translation>Vis berre aktive hendingar</translation>
    </message>
    <message>
        <source>Show Only Today&apos;s Events</source>
        <translation>Vis berre hendingar i dag</translation>
    </message>
    <message>
        <source>Show DayOfWeek:</source>
        <translation>Vis vekedag:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Vekedagar</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sundag</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tysdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Laurdag</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>SKILDRING</translation>
    </message>
    <message>
        <source>LOCATION</source>
        <translation>PLASS</translation>
    </message>
    <message>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <source>END</source>
        <translation>SLUTT</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation>KJELDE</translation>
    </message>
    <message>
        <source>DESTINATION</source>
        <translation>MÅL</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation>OPPHAV</translation>
    </message>
    <message>
        <source>ONE SHOT</source>
        <translation>ENKELTSKOT</translation>
    </message>
    <message>
        <source>TRIM THRESHOLD</source>
        <translation>TRIMMETERSKEL</translation>
    </message>
    <message>
        <source>STARTDATE OFFSET</source>
        <translation>AVVIK STARTDATO</translation>
    </message>
    <message>
        <source>ENDDATE OFFSET</source>
        <translation>AVVIK SLUTTDATO</translation>
    </message>
    <message>
        <source>FORMAT</source>
        <translation>FORMAT</translation>
    </message>
    <message>
        <source>CHANNELS</source>
        <translation>KANALAR</translation>
    </message>
    <message>
        <source>SAMPLE RATE</source>
        <translation>PUNKTPRØVERATE</translation>
    </message>
    <message>
        <source>BIT RATE</source>
        <translation>BITRATE</translation>
    </message>
    <message>
        <source>STATION</source>
        <translation>STASJON</translation>
    </message>
    <message>
        <source>DECK</source>
        <translation>SPELAR</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>KLIPP</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>KORG</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYPE</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>STATUS</translation>
    </message>
    <message>
        <source>EXIT CODE</source>
        <translation>AVSLUTT-KODE</translation>
    </message>
    <message>
        <source>STATE</source>
        <translation>TILSTAND</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>Legg &amp;til</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Rull</translation>
    </message>
    <message>
        <source>Reports</source>
        <translation>Rapportar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Hendinga aktiv</translation>
    </message>
    <message>
        <source>You cannot edit an active event!</source>
        <translation>Du kan ikkje redigera ei aktiv hending!</translation>
    </message>
    <message>
        <source>Are you sure you want to delete event</source>
        <translation>Er du sikker på at du vil sletta hendinga</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Slett hending</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>Greier ikkje kopla til hovud-lydmotoren</translation>
    </message>
    <message>
        <source>Control connection timed out to host</source>
        <translation>Tidsavbrot på kontrolltilkoplinga til verten</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Su</translation>
    </message>
    <message>
        <source>Mo</source>
        <translation>Må</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Ty</translation>
    </message>
    <message>
        <source>We</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>To</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Fr</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>La</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>Hard</source>
        <translation>Hard</translation>
    </message>
    <message>
        <source>Gpi</source>
        <translation>Gpi</translation>
    </message>
    <message>
        <source>Len</source>
        <translation>Len</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>MPEG Layer 1</source>
        <translation>MPEG lag 1</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG lag 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG lag 3</translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation>FLAC</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>Ogg Vorbis</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Korg</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[inga]</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="obsolete">Kort lengd</translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="obsolete">Lågt nivå</translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="obsolete">Høgt nivå</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Lastar ned</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="obsolete">Lastar opp</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="obsolete">Tek opp</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="obsolete">Spelar</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="obsolete">Ventar</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="obsolete">Tenarfeil</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Intern feil</translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="obsolete">Avbrote</translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="obsolete">Eininga er oppteken</translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="obsolete">Inga slik korg/klipp</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
    <message>
        <source>Show Event Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Types</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
